==> gherkin-1.0.7.tar.gz: lib/src/gherkin/runnables/feature.dart <==
import '../exceptions/syntax_error.dart';
import './background.dart';
import './comment_line.dart';
import './debug_information.dart';
import './empty_line.dart';
import './runnable.dart';
import './runnable_block.dart';
import './scenario.dart';
import './scenario_outline.dart';
import './tags.dart';
import './text_line.dart';

class FeatureRunnable extends RunnableBlock {
  String _name;
  String description;
  List<String> tags = <String>[];
  BackgroundRunnable background;
  List<ScenarioRunnable> scenarios = <ScenarioRunnable>[];

  Map<int, Iterable<String>> _tagMap = <int, Iterable<String>>{};

  FeatureRunnable(this._name, RunnableDebugInformation debug) : super(debug);

  @override
  String get name => _name;

  @override
  void addChild(Runnable child) {
    switch (child.runtimeType) {
      case TextLineRunnable:
        description =
            "${description == null ? "" : "$description\n"}${(child as TextLineRunnable).text}";
        break;
      case TagsRunnable:
        tags.addAll((child as TagsRunnable).tags);
        _tagMap.putIfAbsent(
            child.debug.lineNumber, () => (child as TagsRunnable).tags);
        break;
      case ScenarioRunnable:
      case ScenarioOutlineRunnable:
        if (_tagMap.containsKey(child.debug.lineNumber - 1)) {
          (child as ScenarioRunnable).addChild(
              TagsRunnable(null)..tags = _tagMap[child.debug.lineNumber - 1]);
        }

        if (child is ScenarioOutlineRunnable) {
          scenarios.addAll(child.expandOutlinesIntoScenarios());
        } else {
          scenarios.add(child);
        }
        break;
      case BackgroundRunnable:
        if (background == null) {
          background = child;
        } else {
          throw GherkinSyntaxException(
              "Feature file can only contain one backgroung block. File'${debug.filePath}' :: line '${child.debug.lineNumber}'");
        }
        break;
      case EmptyLineRunnable:
      case CommentLineRunnable:
        break;
      default:
        throw Exception(
            "Unknown runnable child given to Feature '${child.runtimeType}' - Line#${child.debug.lineText}: '${child.debug.lineText}'");
    }
  }
}

==> gherkin-1.1.4.tar.gz: lib/src/gherkin/runnables/feature.dart <==
import 'package:gherkin/src/gherkin/runnables/taggable_runnable_block.dart';

import '../exceptions/syntax_error.dart';
import './background.dart';
import './comment_line.dart';
import './debug_information.dart';
import './empty_line.dart';
import './runnable.dart';
import './scenario.dart';
import './scenario_outline.dart';
import './tags.dart';
import './text_line.dart';

class FeatureRunnable extends TaggableRunnableBlock {
  String _name;
  String description;
  BackgroundRunnable background;
  List<ScenarioRunnable> scenarios = <ScenarioRunnable>[];
  List<TagsRunnable> _tagsPendingAssignmentToChild = List<TagsRunnable>();

  FeatureRunnable(this._name, RunnableDebugInformation debug) : super(debug);

  @override
  String get name => _name;

  @override
  void addChild(Runnable child) {
    switch (child.runtimeType) {
      case TextLineRunnable:
        description =
            "${description == null ? "" : "$description\n"}${(child as TextLineRunnable).text}";
        break;
      case TagsRunnable:
        _tagsPendingAssignmentToChild.add(child);
        break;
      case ScenarioRunnable:
      case ScenarioOutlineRunnable:
        Iterable<ScenarioRunnable> childScenarios = [child];
        if (child is ScenarioOutlineRunnable) {
          childScenarios = child.expandOutlinesIntoScenarios();
        }

        scenarios.addAll(childScenarios);
        if (_tagsPendingAssignmentToChild.isNotEmpty) {
          _tagsPendingAssignmentToChild
              .forEach((t) => childScenarios.forEach((s) => s.addTag(t)));
          _tagsPendingAssignmentToChild.clear();
        }

        break;
      case BackgroundRunnable:
        if (background == null) {
          background = child;
        } else {
          throw GherkinSyntaxException(
              "Feature file can only contain one backgroung block. File'${debug.filePath}' :: line '${child.debug.lineNumber}'");
        }
        break;
      case EmptyLineRunnable:
      case CommentLineRunnable:
        break;
      default:
        throw Exception(
            "Unknown runnable child given to Feature '${child.runtimeType}' - Line#${child.debug.lineText}: '${child.debug.lineText}'");
    }
  }

  void onTagAdded(TagsRunnable tag) {
    for (var scenario in scenarios) {
      scenario.addTag(tag.clone(inherited: true));
    }
  }
}
